@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-""" CMFCore product exceptions.
-
-$Id: exceptions.py 110577 2010-04-07 06:33:17Z jens $
-"""
+""" CMFCore product exceptions. """
 
 from AccessControl import ModuleSecurityInfo
 from AccessControl import Unauthorized as AccessControl_Unauthorized
