@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -10,10 +10,7 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Workflow tool xml adapter and setup handler unit tests.
-
-$Id: test_workflow.py 91219 2008-09-17 21:08:48Z tseaver $
-"""
+"""Workflow tool xml adapter and setup handler unit tests. """
 
 import unittest
 import Testing
